@@ -1,6 +1,6 @@
 package CHI::Driver;
 BEGIN {
-  $CHI::Driver::VERSION = '0.39';
+  $CHI::Driver::VERSION = '0.40';
 }
 use Carp;
 use CHI::CacheObject;
@@ -354,7 +354,8 @@ sub get_keys_iterator {
 }
 
 sub clear {
-    my ($self) = @_;
+    my $self = shift;
+    die "clear takes no arguments" if @_;
 
     $self->remove_multi( [ $self->get_keys() ] );
 }
@@ -373,7 +374,13 @@ sub expire {
 }
 
 sub compute {
-    my ( $self, $key, $code, $set_options ) = @_;
+    my $self = shift;
+    my $key  = shift;
+
+    # Allow these in either order for backward compatibility
+    my ( $code, $set_options ) =
+      ( ref( $_[0] ) eq 'CODE' ) ? ( $_[0], $_[1] ) : ( $_[1], $_[0] );
+
     croak "must specify key and code" unless defined($key) && defined($code);
 
     my $value = $self->get($key);
@@ -388,8 +395,10 @@ sub purge {
     my ($self) = @_;
 
     foreach my $key ( $self->get_keys() ) {
-        if ( $self->get_object($key)->is_expired() ) {
-            $self->remove($key);
+        if ( my $obj = $self->get_object($key) ) {
+            if ( $obj->is_expired() ) {
+                $self->remove($key);
+            }
         }
     }
 }
@@ -621,7 +630,7 @@ CHI::Driver - Base class for all CHI drivers
 
 =head1 VERSION
 
-version 0.39
+version 0.40
 
 =head1 DESCRIPTION
 
@@ -651,5 +660,4 @@ the same terms as the Perl 5 programming language system itself.
 
 
 __END__
-# ABSTRACT: Base class for all CHI drivers
 
