@@ -1,11 +1,9 @@
 package CHI::Test::Util;
 BEGIN {
-  $CHI::Test::Util::VERSION = '0.39';
+  $CHI::Test::Util::VERSION = '0.40';
 }
 use Date::Parse;
-use Log::Any::Adapter;
 use Test::Builder;
-use Test::Log::Dispatch;
 use Test::More;
 use strict;
 use warnings;
@@ -15,8 +13,8 @@ our @EXPORT_OK =
   qw(activate_test_logger is_between cmp_bool random_string skip_until);
 
 sub activate_test_logger {
-    my $log = Test::Log::Dispatch->new( min_level => 'debug' );
-    Log::Any::Adapter->set( 'Dispatch', dispatcher => $log );
+    my $log = Log::Any->get_logger( category => 'CHI' );
+    $log->clear();
     return $log;
 }
 
