@@ -1,6 +1,6 @@
 package CHI::t::Driver;
 BEGIN {
-  $CHI::t::Driver::VERSION = '0.39';
+  $CHI::t::Driver::VERSION = '0.40';
 }
 use strict;
 use warnings;
@@ -564,7 +564,7 @@ sub test_serialize : Tests {
 {
     package DummySerializer;
 BEGIN {
-  $DummySerializer::VERSION = '0.39';
+  $DummySerializer::VERSION = '0.40';
 }
     sub serialize   { }
     sub deserialize { }
@@ -1663,4 +1663,21 @@ sub test_missing_params : Tests(13) {
     }
 }
 
+sub test_compute : Tests {
+    my $self  = shift;
+    my $cache = $self->{cache};
+
+    # Test current arg order and pre-0.40 arg order
+    my $expire_time = time + 10;
+    my @orig = ( { expires_at => $expire_time }, sub { 'bar' } );
+    foreach my $args ( [@orig], [ reverse(@orig) ] ) {
+        $cache->clear;
+        is( $cache->get('foo'), undef, "miss" );
+        $cache->compute( 'foo', @$args );
+        is( $cache->get('foo'), 'bar', "hit" );
+        is( $cache->get_object('foo')->expires_at, $expire_time,
+            "expire time" );
+    }
+}
+
 1;
